---
sidebar_position: 1
title: 功能介绍
---

import TableTypes from '/docs/partials/guides/_table-conversation-types.mdx';

# 服务介绍

欢迎使用融云即时通讯。本页面简单介绍了融云即时通讯架构、体系和关键概念。

融云的架构设计特点：

- 无需改变现有 App 的架构，直接嵌入现有代码框架中；
- 无需改变现有 App Server 的架构，独立部署一份用于用户授权的 Service 即可；
- 专注于提供通讯能力，使用私有的二进制通信协议，消息轻量、有序、不丢消息；
- 安全的身份认证和授权方式，无需担心 SDK 能力滥用（盗用身份的垃圾消息、垃圾群发）问题。

融云即时通讯服务不要求在 App 之外建立并行的用户体系，不需要您同步 App 的用户资料到融云，不影响 App 现有的系统架构与帐号体系，与现有业务体系能够实现完美融合。

## 功能特性

融云目前已提供即时通讯产品[单聊]、[群聊]、[超级群]、[聊天室]，在融云业务中，这些产品对应不同的会话类型。

单聊（Private）业务即一对一聊天。群组（Group）业务类似微信群。超级群与聊天室业务均不设用户总数上限。超级群（UltraGroup） 类似 Discord，提供了一种新的群组业务形态，在超级群中提供公有/私有频道、用户组等功能，适用于构建超级社区。聊天室（Chatroom）只有在线用户可接收消息，广泛适用于直播、社区、游戏、广场交友、兴趣讨论等场景。

<TableTypes></TableTypes>

## 高级与扩展功能

IM 服务支持的高级与扩展功能，包括但不限于以下项目：

- **用户管理**：例如用户封禁、用户黑名单（拉黑）、用户白名单，群组及聊天室禁言、聊天室成员封禁等。
- **在线状态订阅**：将用户每一个终端在线、离线或登出后的状态，同步给应用开发者指定的服务器地址。
- **多设备在线消息同步**：同时支持桌面端、移动端、以及多个 Web 端之间的消息在线同步。
- **全量消息路由**：支持将单聊、群组、聊天室、超级群等的消息数据同步到应用开发者指定的服务器地址。
- **内容审核**：支持设置敏感词列表，过滤或替换消息中的敏感词。利用消息回调服务，可将消息先转发到应用开发者指定的服务器地址，由应用服务器判定是否可发送给目标接收者。
- **服务端推送通知**：支持标签推送、包名推送、推送统计、全量用户通知等特性。

> 部分功能需要在控制台开通服务后方可使用。部分为收费增值服务，详见[即时通讯计费细则]。

[即时通讯计费细则]: https://help.rongcloud.cn/t/topic/123

## 服务端

您的后端可利用融云服务端提供的 IM Server API 执行以下操作：

- [获取 Token](/platform-chat-api/user/register)
- [创建群组](/platform-chat-api/group/create-group)
- [将用户加入群组](/platform-chat-api/group/join-group)
- [创建聊天室](/platform-chat-api/chatroom/create)
- [创建超级群](/platform-chat-api/ultragroup/create-ultragroup) 等

部分高级扩展特性仅在 IM Server API 中提供，例如 系统通知、在线用户广播、用户封禁等。详细描述，请参见 [API 接口列表](/platform-chat-api/im-server-api-list-v1)。

即时通讯业务提供[服务端回调（Webhook）](/platform-chat-api/auth-callback)，支持将业务的数据、状态通知同步到您设置的回调地址，例如用户在线状态变更、聊天室房间状态变更等。支持通过回调响应正文的参数控制消息是否发送给接收者。所有服务端回调均需要在控制台分别配置回调地址并启用。

## 客户端

您的应用程序可通过集成 IMLib SDK 和 UI 库来连接到融云服务、传输消息即时消息、以及构建其他功能。

- **即时通讯核心 SDK** ：IMLib SDK 旨在提供一种整合即时通讯通信 (IM) 能力的简单方案。借助 IMLib SDK 封装的通信能力和会话、消息等对象，您可以从头开始构建自己的 UI。请参阅 [IMLib SDK]。
- **即时通讯 UI 库** ：IMKit 和 Global IM UIKit 是 UI 组件库，集成了会话与会话列表界面，并提供了丰富的自定义功能，可简化您的集成体验。请参阅 [IMKit] 以及 [Global IM UIKit]。

只要客户端（包括应用服务端）使用一致的 App Key，不同平台、不同版本 SDK 的客户端之间可以互通消息。

## 控制台

[控制台](https://console.rongcloud.cn/)作为一个综合服务平台，提供对 App Key、App Secret、计费操作和各种其他功能配置的一站式访问与管理能力。

您还可以使用控制台调试 IM Server API、查询消息状态、查询连接状态、添加 Webhook 等等。

![开发门户|600x300](/static/guides/dev-portal-config.png)

## 数据与隐私

融云不会利用客户的数据。同时融云提供完善的数据隐私保护策略，欢迎了解 [SDK 隐私政策]。

如果需要存储、查看、获取与即时通讯相关的数据，请参考以下方式：

- 如需在云端长期存储单聊会话、群聊会话、聊天室会话的历史消息，您可以[开通消息云存储服务]。默认的长期存储时长与业务类型相关，可按需调整。该服务存储的数据仅供客户端获取历史消息时使用。
- 如需直接下载应用下全部用户的消息历史，请[开通 Server API 历史消息日志下载]。开通后可使用服务端 API 获取最多三天的消息日志。
- 除此之外，您还可以[开通全量消息路由]服务，实时将消息同步到您的业务服务器。
- 您可以前往[融云控制台数据统计页面]，查看即时通讯用户统计、业务统计、消息统计、业务健康检查等数据。开通相应服务后，还能获取如业务数据分析等数据。

[server-sdk-java-github]: https://github.com/rongcloud/server-sdk-java
[server-sdk-php-github]: https://github.com/rongcloud/server-sdk-php
[server-sdk-go-github]: https://github.com/rongcloud/server-sdk-go/tree/v3
[server-sdk-java-gitee]: https://gitee.com/rongcloud/server-sdk-java
[server-sdk-php-gitee]: https://gitee.com/rongcloud/server-sdk-php
[server-sdk-go-gitee]: https://gitee.com/rongcloud/server-sdk-go/tree/v3
[单聊]: https://www.rongcloud.cn/product/single-chat
[群聊]: https://www.rongcloud.cn/product/group-chat
[聊天室]: https://www.rongcloud.cn/product/chatroom
[超级群]: https://www.rongcloud.cn/product/ultragroup
[Global IM UIKit]: ../sdk-libraries/client-sdks/imkit
[IMKit]: ../sdk-libraries/client-sdks/imkit
[IMLib SDK]: ../sdk-libraries/client-sdks/imlib
[融云控制台]: https://console.rongcloud.cn
[服务管理]: https://console.rongcloud.cn/agile/formwork/app/appService
[开通消息云存储服务]: https://console.rongcloud.cn/agile/formwork/advance/index
[开通 Server API 历史消息日志下载]: https://console.rongcloud.cn/agile/formwork/baseService/index
[开通全量消息路由]: https://console.rongcloud.cn/agile/formwork/advance/index
[融云控制台数据统计页面]: https://console.rongcloud.cn/agile/formwork/stat/index
[SDK 隐私政策]: /guides/privacy

